@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "qmljstypedescriptionreader.h"
 
@@ -40,9 +37,10 @@
 
 #include "qmljsbind.h"
 #include "qmljsinterpreter.h"
+#include "qmljsutils.h"
 
-#include <QtCore/QIODevice>
-#include <QtCore/QBuffer>
+#include <QIODevice>
+#include <QBuffer>
 
 using namespace QmlJS;
 using namespace QmlJS::AST;
@@ -58,7 +56,9 @@ TypeDescriptionReader::~TypeDescriptionReader()
 {
 }
 
-bool TypeDescriptionReader::operator()(QHash<QString, FakeMetaObject::ConstPtr> *objects)
+bool TypeDescriptionReader::operator()(
+        QHash<QString, FakeMetaObject::ConstPtr> *objects,
+        QList<ModuleApiInfo> *moduleApis)
 {
     Engine engine;
 
@@ -76,6 +76,7 @@ bool TypeDescriptionReader::operator()(QHash<QString, FakeMetaObject::ConstPtr>
     }
 
     _objects = objects;
+    _moduleApis = moduleApis;
     readDocument(parser.ast());
 
     return _errorMessage.isEmpty();
@@ -104,7 +105,7 @@ void TypeDescriptionReader::readDocument(UiProgram *ast)
     }
 
     UiImport *import = ast->imports->import;
-    if (Bind::toString(import->importUri) != QLatin1String("QtQuick.tooling")) {
+    if (toString(import->importUri) != QLatin1String("QtQuick.tooling")) {
         addError(import->importToken, "Expected import of QtQuick.tooling");
         return;
     }
@@ -132,7 +133,7 @@ void TypeDescriptionReader::readDocument(UiProgram *ast)
         return;
     }
 
-    if (Bind::toString(module->qualifiedTypeNameId) != "Module") {
+    if (toString(module->qualifiedTypeNameId) != "Module") {
         addError(SourceLocation(), "Expected document to contain a Module {} member");
         return;
     }
@@ -145,14 +146,21 @@ void TypeDescriptionReader::readModule(UiObjectDefinition *ast)
     for (UiObjectMemberList *it = ast->initializer->members; it; it = it->next) {
         UiObjectMember *member = it->member;
         UiObjectDefinition *component = dynamic_cast<UiObjectDefinition *>(member);
-        const QString typeName = Bind::toString(component->qualifiedTypeNameId);
+
+        QString typeName;
+        if (component)
+            typeName = toString(component->qualifiedTypeNameId);
+
         if (!component || (typeName != "Component" && typeName != "ModuleApi")) {
             addWarning(member->firstSourceLocation(), "Expected only 'Component' and 'ModuleApi' object definitions");
             continue;
         }
 
-        if (typeName == QLatin1String("Component"))
+        if (typeName == QLatin1String("Component")) {
             readComponent(component);
+        } else if (typeName == QLatin1String("ModuleApi")) {
+            readModuleApi(component);
+        }
     }
 }
 
@@ -181,7 +189,7 @@ void TypeDescriptionReader::readComponent(UiObjectDefinition *ast)
         UiObjectDefinition *component = dynamic_cast<UiObjectDefinition *>(member);
         UiScriptBinding *script = dynamic_cast<UiScriptBinding *>(member);
         if (component) {
-            QString name = Bind::toString(component->qualifiedTypeNameId);
+            QString name = toString(component->qualifiedTypeNameId);
             if (name == "Property") {
                 readProperty(component, fmo);
             } else if (name == "Method" || name == "Signal") {
@@ -192,7 +200,7 @@ void TypeDescriptionReader::readComponent(UiObjectDefinition *ast)
                 addWarning(component->firstSourceLocation(), "Expected only Property, Method, Signal and Enum object definitions");
             }
         } else if (script) {
-            QString name = Bind::toString(script->qualifiedId);
+            QString name = toString(script->qualifiedId);
             if (name == "name") {
                 fmo->setClassName(readStringBinding(script));
             } else if (name == "prototype") {
@@ -207,7 +215,7 @@ void TypeDescriptionReader::readComponent(UiObjectDefinition *ast)
                 fmo->setAttachedTypeName(readStringBinding(script));
             } else {
                 addWarning(script->firstSourceLocation(),
-                           "Expected only name, prototype, defaultProperty, attachedType, exports"
+                           "Expected only name, prototype, defaultProperty, attachedType, exports "
                            "and exportMetaObjectRevisions script bindings");
             }
         } else {
@@ -225,6 +233,40 @@ void TypeDescriptionReader::readComponent(UiObjectDefinition *ast)
     _objects->insert(fmo->className(), fmo);
 }
 
+void TypeDescriptionReader::readModuleApi(UiObjectDefinition *ast)
+{
+    ModuleApiInfo apiInfo;
+
+    for (UiObjectMemberList *it = ast->initializer->members; it; it = it->next) {
+        UiObjectMember *member = it->member;
+        UiScriptBinding *script = dynamic_cast<UiScriptBinding *>(member);
+
+        if (script) {
+            const QString name = toString(script->qualifiedId);
+            if (name == "uri") {
+                apiInfo.uri = readStringBinding(script);
+            } else if (name == "version") {
+                apiInfo.version = readNumericVersionBinding(script);
+            } else if (name == "name") {
+                apiInfo.cppName = readStringBinding(script);
+            } else {
+                addWarning(script->firstSourceLocation(),
+                           "Expected only uri, version and name script bindings");
+            }
+        } else {
+            addWarning(member->firstSourceLocation(), "Expected only script bindings");
+        }
+    }
+
+    if (!apiInfo.version.isValid()) {
+        addError(ast->firstSourceLocation(), "ModuleApi definition has no or invalid 'version' binding");
+        return;
+    }
+
+    if (_moduleApis)
+        _moduleApis->append(apiInfo);
+}
+
 void TypeDescriptionReader::readSignalOrMethod(UiObjectDefinition *ast, bool isMethod, FakeMetaObject::Ptr fmo)
 {
     FakeMetaMethod fmm;
@@ -239,14 +281,14 @@ void TypeDescriptionReader::readSignalOrMethod(UiObjectDefinition *ast, bool isM
         UiObjectDefinition *component = dynamic_cast<UiObjectDefinition *>(member);
         UiScriptBinding *script = dynamic_cast<UiScriptBinding *>(member);
         if (component) {
-            QString name = Bind::toString(component->qualifiedTypeNameId);
+            QString name = toString(component->qualifiedTypeNameId);
             if (name == "Parameter") {
                 readParameter(component, &fmm);
             } else {
                 addWarning(component->firstSourceLocation(), "Expected only Parameter object definitions");
             }
         } else if (script) {
-            QString name = Bind::toString(script->qualifiedId);
+            QString name = toString(script->qualifiedId);
             if (name == "name") {
                 fmm.setMethodName(readStringBinding(script));
             } else if (name == "type") {
@@ -287,7 +329,7 @@ void TypeDescriptionReader::readProperty(UiObjectDefinition *ast, FakeMetaObject
             continue;
         }
 
-        QString id = Bind::toString(script->qualifiedId);
+        QString id = toString(script->qualifiedId);
         if (id == "name") {
             name = readStringBinding(script);
         } else if (id == "type") {
@@ -325,7 +367,7 @@ void TypeDescriptionReader::readEnum(UiObjectDefinition *ast, FakeMetaObject::Pt
             continue;
         }
 
-        QString name = Bind::toString(script->qualifiedId);
+        QString name = toString(script->qualifiedId);
         if (name == "name") {
             fme.setName(readStringBinding(script));
         } else if (name == "values") {
@@ -351,9 +393,9 @@ void TypeDescriptionReader::readParameter(UiObjectDefinition *ast, FakeMetaMetho
             continue;
         }
 
-        QString id = Bind::toString(script->qualifiedId);
+        const QString id = toString(script->qualifiedId);
         if (id == "name") {
-            id = readStringBinding(script);
+            name = readStringBinding(script);
         } else if (id == "type") {
             type = readStringBinding(script);
         } else if (id == "isPointer") {
@@ -437,6 +479,30 @@ double TypeDescriptionReader::readNumericBinding(AST::UiScriptBinding *ast)
     return numericLit->value;
 }
 
+ComponentVersion TypeDescriptionReader::readNumericVersionBinding(UiScriptBinding *ast)
+{
+    ComponentVersion invalidVersion;
+
+    if (!ast || !ast->statement) {
+        addError(ast->colonToken, "Expected numeric literal after colon");
+        return invalidVersion;
+    }
+
+    ExpressionStatement *expStmt = AST::cast<ExpressionStatement *>(ast->statement);
+    if (!expStmt) {
+        addError(ast->statement->firstSourceLocation(), "Expected numeric literal after colon");
+        return invalidVersion;
+    }
+
+    NumericLiteral *numericLit = AST::cast<NumericLiteral *>(expStmt->expression);
+    if (!numericLit) {
+        addError(expStmt->firstSourceLocation(), "Expected numeric literal after colon");
+        return invalidVersion;
+    }
+
+    return ComponentVersion(_source.mid(numericLit->literalToken.begin(), numericLit->literalToken.length));
+}
+
 int TypeDescriptionReader::readIntBinding(AST::UiScriptBinding *ast)
 {
     double v = readNumericBinding(ast);
