@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "pathchooser.h"
 
@@ -38,18 +35,18 @@
 
 #include "synchronousprocess.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QSettings>
-#include <QtCore/QProcess>
+#include <QDebug>
+#include <QDir>
+#include <QFileInfo>
+#include <QSettings>
+#include <QProcess>
 
-#include <QtGui/qevent.h>
-#include <QtGui/QDesktopServices>
-#include <QtGui/QFileDialog>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
+#include <qevent.h>
+#include <QDesktopServices>
+#include <QFileDialog>
+#include <QHBoxLayout>
+#include <QLineEdit>
+#include <QPushButton>
 
 /*!
     \class Utils::PathChooser
@@ -61,7 +58,7 @@
 */
 
 /*static*/ const char * const Utils::PathChooser::browseButtonLabel =
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
                    QT_TRANSLATE_NOOP("Utils::PathChooser", "Choose...");
 #else
                    QT_TRANSLATE_NOOP("Utils::PathChooser", "Browse...");
@@ -131,7 +128,7 @@ bool BinaryVersionToolTipEventFilter::eventFilter(QObject *o, QEvent *e)
     if (e->type() != QEvent::ToolTip)
         return false;
     QLineEdit *le = qobject_cast<QLineEdit *>(o);
-    QTC_ASSERT(le, return false; )
+    QTC_ASSERT(le, return false);
 
     const QString binary = le->text();
     if (!binary.isEmpty()) {
@@ -166,7 +163,8 @@ QString BinaryVersionToolTipEventFilter::toolVersion(const QString &binary, cons
         Utils::SynchronousProcess::stopProcess(proc);
         return QString();
     }
-    return QString::fromLocal8Bit(proc.readAllStandardOutput());
+    return QString::fromLocal8Bit(QByteArray(proc.readAllStandardOutput()
+        + proc.readAllStandardError()));
 }
 
 // Extends BinaryVersionToolTipEventFilter to prepend the existing pathchooser
@@ -203,6 +201,7 @@ public:
     QString m_baseDirectory;
     Environment m_environment;
     BinaryVersionToolTipEventFilter *m_binaryVersionToolTipEventFilter;
+    QList<QAbstractButton *> m_buttons;
 };
 
 PathChooserPrivate::PathChooserPrivate(PathChooser *chooser) :
@@ -269,16 +268,22 @@ PathChooser::~PathChooser()
 }
 
 void PathChooser::addButton(const QString &text, QObject *receiver, const char *slotFunc)
+{
+    insertButton(d->m_buttons.count(), text, receiver, slotFunc);
+}
+
+void PathChooser::insertButton(int index, const QString &text, QObject *receiver, const char *slotFunc)
 {
     QPushButton *button = new QPushButton;
     button->setText(text);
     connect(button, SIGNAL(clicked()), receiver, slotFunc);
-    d->m_hLayout->addWidget(button);
+    d->m_hLayout->insertWidget(index + 1/*line edit*/, button);
+    d->m_buttons.insert(index, button);
 }
 
 QAbstractButton *PathChooser::buttonAtIndex(int index) const
 {
-    return findChildren<QAbstractButton*>().at(index);
+    return d->m_buttons.at(index);
 }
 
 QString PathChooser::baseDirectory() const
@@ -291,6 +296,16 @@ void PathChooser::setBaseDirectory(const QString &directory)
     d->m_baseDirectory = directory;
 }
 
+FileName PathChooser::baseFileName() const
+{
+    return Utils::FileName::fromString(d->m_baseDirectory);
+}
+
+void PathChooser::setBaseFileName(const FileName &base)
+{
+    d->m_baseDirectory = base.toString();
+}
+
 void PathChooser::setEnvironment(const Utils::Environment &env)
 {
     QString oldExpand = path();
@@ -309,11 +324,21 @@ QString PathChooser::rawPath() const
     return QDir::fromNativeSeparators(d->m_lineEdit->text());
 }
 
+FileName PathChooser::fileName() const
+{
+    return Utils::FileName::fromString(path());
+}
+
 void PathChooser::setPath(const QString &path)
 {
     d->m_lineEdit->setText(QDir::toNativeSeparators(path));
 }
 
+void PathChooser::setFileName(const Utils::FileName &fn)
+{
+    d->m_lineEdit->setText(fn.toUserOutput());
+}
+
 bool PathChooser::isReadOnly() const
 {
     return d->m_lineEdit->isReadOnly();
@@ -322,8 +347,7 @@ bool PathChooser::isReadOnly() const
 void PathChooser::setReadOnly(bool b)
 {
     d->m_lineEdit->setReadOnly(b);
-    const QList<QAbstractButton *> &allButtons = findChildren<QAbstractButton *>();
-    foreach (QAbstractButton *button, allButtons)
+    foreach (QAbstractButton *button, d->m_buttons)
         button->setEnabled(!b);
 }
 
@@ -573,7 +597,7 @@ QString PathChooser::makeDialogTitle(const QString &title)
         return d->m_dialogTitleOverride;
 }
 
-QLineEdit *PathChooser::lineEdit() const
+FancyLineEdit *PathChooser::lineEdit() const
 {
     // HACK: Make it work with HistoryCompleter.
     if (d->m_lineEdit->objectName().isEmpty())
