@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "basefilewizard.h"
 
@@ -44,20 +41,19 @@
 #include <utils/stringutils.h>
 #include <utils/fileutils.h>
 
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QVector>
-#include <QtCore/QDebug>
-#include <QtCore/QSharedData>
-#include <QtCore/QEventLoop>
-#include <QtCore/QSharedPointer>
-#include <QtCore/QScopedPointer>
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
+#include <QVector>
+#include <QDebug>
+#include <QSharedData>
+#include <QEventLoop>
+#include <QSharedPointer>
+#include <QScopedPointer>
 
-#include <QtGui/QMessageBox>
-#include <QtGui/QWizard>
-#include <QtGui/QMainWindow>
-#include <QtGui/QIcon>
+#include <QMessageBox>
+#include <QWizard>
+#include <QIcon>
 
 enum { debugWizard = 0 };
 
@@ -86,6 +82,9 @@ public:
     QString id;
     QString category;
     QString displayCategory;
+    Core::FeatureSet requiredFeatures;
+    Core::IWizard::WizardFlags flags;
+    QString descriptionImage;
 };
 
 BaseFileWizardParameterData::BaseFileWizardParameterData(IWizard::WizardKind k) :
@@ -145,7 +144,8 @@ CORE_EXPORT QDebug operator<<(QDebug d, const BaseFileWizardParameters &p)
                 << " Category: " << p.category()
                 << " DisplayName: " << p.displayName()
                 << " Description: " << p.description()
-                << " DisplayCategory: " << p.displayCategory();
+                << " DisplayCategory: " << p.displayCategory()
+                << " Required Features: " << p.requiredFeatures().toStringList();
     return d;
 }
 
@@ -214,11 +214,42 @@ QString BaseFileWizardParameters::displayCategory() const
     return m_d->displayCategory;
 }
 
+Core::FeatureSet BaseFileWizardParameters::requiredFeatures() const
+{
+    return m_d->requiredFeatures;
+}
+
+void BaseFileWizardParameters::setRequiredFeatures(Core::FeatureSet features)
+{
+
+    m_d->requiredFeatures = features;
+}
+
 void BaseFileWizardParameters::setDisplayCategory(const QString &v)
 {
     m_d->displayCategory = v;
 }
 
+Core::IWizard::WizardFlags BaseFileWizardParameters::flags() const
+{
+    return m_d->flags;
+}
+
+void BaseFileWizardParameters::setFlags(Core::IWizard::WizardFlags flags)
+{
+    m_d->flags = flags;
+}
+
+QString BaseFileWizardParameters::descriptionImage() const
+{
+  return m_d->descriptionImage;
+}
+
+void BaseFileWizardParameters::setDescriptionImage(const QString &path)
+{
+    m_d->descriptionImage = path;
+}
+
 /*!
     \class Core::Internal::WizardEventLoop
     \brief Special event loop that runs a QWizard and terminates if the page changes.
@@ -349,6 +380,11 @@ BaseFileWizard::BaseFileWizard(const BaseFileWizardParameters &parameters,
 {
 }
 
+BaseFileWizardParameters BaseFileWizard::baseFileWizardParameters() const
+{
+    return d->m_parameters;
+}
+
 BaseFileWizard::~BaseFileWizard()
 {
     delete d;
@@ -389,7 +425,12 @@ QString BaseFileWizard::displayCategory() const
     return d->m_parameters.displayCategory();
 }
 
-void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
+QString BaseFileWizard::descriptionImage() const
+{
+       return d->m_parameters.descriptionImage();
+}
+
+void BaseFileWizard::runWizard(const QString &path, QWidget *parent, const QString &platform, const QVariantMap &extraValues)
 {
     QTC_ASSERT(!path.isEmpty(), return);
 
@@ -397,7 +438,7 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
 
     QString errorMessage;
     // Compile extension pages, purge out unused ones
-    ExtensionList extensions = ExtensionSystem::PluginManager::instance()->getObjects<IFileWizardExtension>();
+    ExtensionList extensions = ExtensionSystem::PluginManager::getObjects<IFileWizardExtension>();
     WizardPageList  allExtensionPages;
     for (ExtensionList::iterator it = extensions.begin(); it !=  extensions.end(); ) {
         const WizardPageList extensionPages = (*it)->extensionPages(this);
@@ -419,7 +460,18 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
     // Create dialog and run it. Ensure that the dialog is deleted when
     // leaving the func, but not before the IFileWizardExtension::process
     // has been called
-    const QScopedPointer<QWizard> wizard(createWizardDialog(parent, path, allExtensionPages));
+
+    WizardDialogParameters::DialogParameterFlags dialogParameterFlags;
+
+    if (flags().testFlag(ForceCapitalLetterForFileName))
+        dialogParameterFlags |= WizardDialogParameters::ForceCapitalLetterForFileName;
+
+    const QScopedPointer<QWizard> wizard(createWizardDialog(parent, WizardDialogParameters(path,
+                                                                                           allExtensionPages,
+                                                                                           platform,
+                                                                                           requiredFeatures(),
+                                                                                           dialogParameterFlags,
+                                                                                           extraValues)));
     QTC_ASSERT(!wizard.isNull(), return);
 
     GeneratedFiles files;
@@ -445,7 +497,7 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
         }
         if (firstExtensionPageHit)
             foreach (IFileWizardExtension *ex, extensions)
-                ex->firstExtensionPageShown(files);
+                ex->firstExtensionPageShown(files, extraValues);
         if (accepted)
             break;
     }
@@ -497,6 +549,17 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
         QMessageBox::critical(0, tr("File Generation Failure"), errorMessage);
 }
 
+
+Core::FeatureSet BaseFileWizard::requiredFeatures() const
+{
+    return d->m_parameters.requiredFeatures();
+}
+
+Core::IWizard::WizardFlags BaseFileWizard::flags() const
+{
+    return d->m_parameters.flags();
+}
+
 /*!
     \fn virtual QWizard *Core::BaseFileWizard::createWizardDialog(QWidget *parent,
                                                                   const QString &defaultPath,
@@ -588,10 +651,9 @@ bool BaseFileWizard::postGenerateFiles(const QWizard *, const GeneratedFiles &l,
 
 bool BaseFileWizard::postGenerateOpenEditors(const GeneratedFiles &l, QString *errorMessage)
 {
-    Core::EditorManager *em = Core::EditorManager::instance();
     foreach(const Core::GeneratedFile &file, l) {
         if (file.attributes() & Core::GeneratedFile::OpenEditorAttribute) {
-            if (!em->openEditor(file.path(), file.editorId(), Core::EditorManager::ModeSwitch )) {
+            if (!Core::EditorManager::openEditor(file.path(), file.editorId(), Core::EditorManager::ModeSwitch )) {
                 if (errorMessage)
                     *errorMessage = tr("Failed to open an editor for '%1'.").arg(QDir::toNativeSeparators(file.path()));
                 return false;
@@ -676,7 +738,7 @@ BaseFileWizard::OverwriteResult BaseFileWizard::promptOverwrite(GeneratedFiles *
     // Set 'keep' attribute in files
     foreach (const QString &keepFile, existingFilesToKeep) {
         const int i = indexOfFile(*files, keepFile);
-        QTC_ASSERT(i != -1, return OverwriteCanceled; )
+        QTC_ASSERT(i != -1, return OverwriteCanceled);
         GeneratedFile &file = (*files)[i];
         file.setAttributes(file.attributes() | GeneratedFile::KeepExistingFileAttribute);
     }
@@ -713,7 +775,7 @@ QString BaseFileWizard::buildFileName(const QString &path,
 
 QString BaseFileWizard::preferredSuffix(const QString &mimeType)
 {
-    const QString rc = Core::ICore::instance()->mimeDatabase()->preferredSuffixByType(mimeType);
+    const QString rc = Core::ICore::mimeDatabase()->preferredSuffixByType(mimeType);
     if (rc.isEmpty())
         qWarning("%s: WARNING: Unable to find a preferred suffix for %s.",
                  Q_FUNC_INFO, mimeType.toUtf8().constData());
@@ -749,14 +811,15 @@ StandardFileWizard::StandardFileWizard(const BaseFileWizardParameters &parameter
 */
 
 QWizard *StandardFileWizard::createWizardDialog(QWidget *parent,
-                                                const QString &defaultPath,
-                                                const WizardPageList &extensionPages) const
+                                                const WizardDialogParameters &wizardDialogParameters) const
 {
     Utils::FileWizardDialog *standardWizardDialog = new Utils::FileWizardDialog(parent);
+    if (wizardDialogParameters.flags().testFlag(WizardDialogParameters::ForceCapitalLetterForFileName))
+        standardWizardDialog->setForceFirstCapitalLetterForFileName(true);
     standardWizardDialog->setWindowTitle(tr("New %1").arg(displayName()));
     setupWizard(standardWizardDialog);
-    standardWizardDialog->setPath(defaultPath);
-    foreach (QWizardPage *p, extensionPages)
+    standardWizardDialog->setPath(wizardDialogParameters.defaultPath());
+    foreach (QWizardPage *p, wizardDialogParameters.extensionPages())
         BaseFileWizard::applyExtensionPageShortTitle(standardWizardDialog, standardWizardDialog->addPage(p));
     return standardWizardDialog;
 }
