@@ -1,42 +1,39 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef DEBUGGER_BREAKPOINT_H
 #define DEBUGGER_BREAKPOINT_H
 
-#include <QtCore/QDebug>
-#include <QtCore/QList>
-#include <QtCore/QMetaType>
-#include <QtCore/QString>
+#include <QDebug>
+#include <QList>
+#include <QMetaType>
+#include <QString>
 
 namespace Debugger {
 namespace Internal {
@@ -140,7 +137,7 @@ enum BreakpointType
     BreakpointAtSysCall,
     WatchpointAtAddress,
     WatchpointAtExpression,
-    BreakpointOnQmlSignalHandler,
+    BreakpointOnQmlSignalEmit,
     BreakpointAtJavaScriptThrow
 };
 
@@ -176,7 +173,6 @@ enum BreakpointParts
     ConditionPart = 0x10,
     IgnoreCountPart = 0x20,
     ThreadSpecPart = 0x40,
-    AllConditionParts = ConditionPart|IgnoreCountPart|ThreadSpecPart,
     ModulePart = 0x80,
     TracePointPart = 0x100,
 
@@ -185,11 +181,16 @@ enum BreakpointParts
     PathUsagePart = 0x800,
     CommandPart = 0x1000,
     MessagePart = 0x2000,
+    OneShotPart = 0x4000,
+
+    AllConditionParts = ConditionPart|IgnoreCountPart|ThreadSpecPart
+               |OneShotPart,
 
     AllParts = FileAndLinePart|FunctionPart
                |ExpressionPart|AddressPart|ConditionPart
                |IgnoreCountPart|ThreadSpecPart|ModulePart|TracePointPart
                |EnabledPart|TypePart|PathUsagePart|CommandPart|MessagePart
+               |OneShotPart
 };
 
 inline void operator|=(BreakpointParts &p, BreakpointParts r)
@@ -211,6 +212,7 @@ public:
     // Enough for now.
     bool isBreakpoint() const { return !isWatchpoint() && !isTracepoint(); }
     bool isTracepoint() const { return tracepoint; }
+    bool isCppBreakpoint() const;
     QString toString() const;
     void updateLocation(const QByteArray &location); // file.cpp:42
 
@@ -235,6 +237,7 @@ public:
     QString command;         //!< command to execute
     QString message;         //!< message
     bool tracepoint;
+    bool oneShot;            //!< Should this breakpoint trigger only once?
 };
 
 class BreakpointResponse : public BreakpointParameters
