@@ -1,50 +1,48 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (info@qt.nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at info@qt.nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef GITPLUGIN_H
 #define GITPLUGIN_H
 
-#include "settingspage.h"
+#include "gitsettings.h"
+
 #include "vcsbase/vcsbaseplugin.h"
 
 #include <coreplugin/editormanager/ieditorfactory.h>
 #include <extensionsystem/iplugin.h>
 
-#include <QtCore/QObject>
-#include <QtCore/QProcess>
-#include <QtCore/QStringList>
-#include <QtCore/QPointer>
-#include <QtCore/QPair>
-#include <QtCore/QVector>
+#include <QObject>
+#include <QProcess>
+#include <QStringList>
+#include <QPointer>
+#include <QPair>
+#include <QVector>
 
 QT_BEGIN_NAMESPACE
 class QFile;
@@ -54,7 +52,6 @@ QT_END_NAMESPACE
 
 namespace Core {
 class IEditorFactory;
-class ICore;
 class Command;
 class Context;
 class ActionManager;
@@ -69,13 +66,11 @@ namespace Locator {
 namespace Git {
 namespace Internal {
 
-class GitPlugin;
 class GitVersionControl;
 class GitClient;
 class ChangeSelectionDialog;
 class GitSubmitEditor;
-struct CommitData;
-struct GitSettings;
+class CommitData;
 class StashDialog;
 class BranchDialog;
 class RemoteDialog;
@@ -85,9 +80,10 @@ typedef void (GitClient::*GitClientMemberFunc)(const QString &);
 typedef QPair<QAction *, Core::Command* > ActionCommandPair;
 typedef QPair<Utils::ParameterAction *, Core::Command* > ParameterActionCommandPair;
 
-class GitPlugin : public VCSBase::VCSBasePlugin
+class GitPlugin : public VcsBase::VcsBasePlugin
 {
     Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QtCreatorPlugin" FILE "Git.json")
 
 public:
     GitPlugin();
@@ -95,11 +91,11 @@ public:
 
     static GitPlugin *instance();
 
-    virtual bool initialize(const QStringList &arguments, QString *error_message);
+    virtual bool initialize(const QStringList &arguments, QString *errorMessage);
 
     GitVersionControl *gitVersionControl() const;
 
-    GitSettings settings() const;
+    const GitSettings &settings() const;
     void setSettings(const GitSettings &s);
 
     GitClient *gitClient() const;
@@ -115,7 +111,7 @@ private slots:
     void logProject();
     void undoFileChanges(bool revertStaging = true);
     void undoUnstagedFileChanges();
-    void undoRepositoryChanges();
+    void resetRepository();
     void stageFile();
     void unstageFile();
     void cleanProject();
@@ -137,45 +133,46 @@ private slots:
     void push();
 
 protected:
-    virtual void updateActions(VCSBase::VCSBasePlugin::ActionState);
-    virtual bool submitEditorAboutToClose(VCSBase::VCSBaseSubmitEditor *submitEditor);
+    virtual void updateActions(VcsBase::VcsBasePlugin::ActionState);
+    virtual bool submitEditorAboutToClose(VcsBase::VcsBaseSubmitEditor *submitEditor);
 
 private:
     inline ParameterActionCommandPair
-            createParameterAction(Core::ActionManager *am, Core::ActionContainer *ac,
+            createParameterAction(Core::ActionContainer *ac,
                                   const QString &defaultText, const QString &parameterText,
-                                  const QString &id, const Core::Context &context, bool addToLocator);
+                                  const Core::Id &id, const Core::Context &context, bool addToLocator);
 
     inline ParameterActionCommandPair
-            createFileAction(Core::ActionManager *am, Core::ActionContainer *ac,
+            createFileAction(Core::ActionContainer *ac,
                              const QString &defaultText, const QString &parameterText,
-                             const QString &id, const Core::Context &context, bool addToLocator,
+                             const Core::Id &id, const Core::Context &context, bool addToLocator,
                              const char *pluginSlot);
 
     inline ParameterActionCommandPair
-            createProjectAction(Core::ActionManager *am, Core::ActionContainer *ac,
+            createProjectAction(Core::ActionContainer *ac,
                                 const QString &defaultText, const QString &parameterText,
-                                const QString &id, const Core::Context &context, bool addToLocator);
+                                const Core::Id &id, const Core::Context &context, bool addToLocator);
 
     inline ParameterActionCommandPair
-                createProjectAction(Core::ActionManager *am, Core::ActionContainer *ac,
+                createProjectAction(Core::ActionContainer *ac,
                                     const QString &defaultText, const QString &parameterText,
-                                    const QString &id, const Core::Context &context, bool addToLocator,
+                                    const Core::Id &id, const Core::Context &context, bool addToLocator,
                                     const char *pluginSlot);
 
 
-    inline ActionCommandPair createRepositoryAction(Core::ActionManager *am, Core::ActionContainer *ac,
-                                           const QString &text, const QString &id,
+    inline ActionCommandPair createRepositoryAction(Core::ActionContainer *ac,
+                                           const QString &text, const Core::Id &id,
                                            const Core::Context &context, bool addToLocator);
-    inline ActionCommandPair createRepositoryAction(Core::ActionManager *am, Core::ActionContainer *ac,
-                                           const QString &text, const QString &id,
+    inline ActionCommandPair createRepositoryAction(Core::ActionContainer *ac,
+                                           const QString &text, const Core::Id &id,
                                            const Core::Context &context,
                                            bool addToLocator, const char *pluginSlot);
-    inline ActionCommandPair createRepositoryAction(Core::ActionManager *am, Core::ActionContainer *ac,
-                                           const QString &text, const QString &id,
+    inline ActionCommandPair createRepositoryAction(Core::ActionContainer *ac,
+                                           const QString &text, const Core::Id &id,
                                            const Core::Context &context,
                                            bool addToLocator, GitClientMemberFunc);
 
+    void updateRepositoryBrowserAction();
     bool isCommitEditorOpen() const;
     Core::IEditor *openSubmitEditor(const QString &fileName, const CommitData &cd, bool amend);
     void cleanCommitMessageFile();
@@ -184,7 +181,6 @@ private:
     void startCommit(bool amend);
 
     static GitPlugin *m_instance;
-    Core::ICore *m_core;
     Locator::CommandLocator *m_commandLocator;
     QAction *m_createRepositoryAction;
 
@@ -195,6 +191,7 @@ private:
     QAction *m_undoAction;
     QAction *m_redoAction;
     QAction *m_menuAction;
+    QAction *m_repositoryBrowserAction;
 
     QVector<Utils::ParameterAction *> m_fileActions;
     QVector<Utils::ParameterAction *> m_projectActions;
@@ -207,12 +204,11 @@ private:
     QPointer<BranchDialog>      m_branchDialog;
     QPointer<RemoteDialog>      m_remoteDialog;
     QString                     m_submitRepository;
-    QStringList                 m_submitOrigCommitFiles;
-    QStringList                 m_submitOrigDeleteFiles;
     QString                     m_commitMessageFileName;
     QString                     m_commitAmendSHA1;
     bool                        m_submitActionTriggered;
 
+    GitSettings m_settings;
 };
 
 } // namespace Git
