@@ -1,59 +1,56 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (info@qt.nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at info@qt.nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "dependenciespanel.h"
 #include "project.h"
 #include "session.h"
 
 #include <coreplugin/fileiconprovider.h>
-#include <coreplugin/ifile.h>
+#include <coreplugin/idocument.h>
 #include <utils/detailswidget.h>
 
-#include <QtCore/QVector>
-#include <QtCore/QDebug>
-#include <QtCore/QSize>
-#include <QtCore/QCoreApplication>
+#include <QVector>
+#include <QDebug>
+#include <QSize>
+#include <QCoreApplication>
 
-#include <QtGui/QLabel>
-#include <QtGui/QApplication>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QTreeView>
-#include <QtGui/QSpacerItem>
-#include <QtGui/QHeaderView>
-#include <QtGui/QMessageBox>
-#include <QtGui/QPushButton>
-#include <QtGui/QToolButton>
-#include <QtGui/QWidget>
-#include <QtGui/QLabel>
+#include <QLabel>
+#include <QApplication>
+#include <QHBoxLayout>
+#include <QTreeView>
+#include <QSpacerItem>
+#include <QHeaderView>
+#include <QMessageBox>
+#include <QPushButton>
+#include <QToolButton>
+#include <QWidget>
+#include <QLabel>
 
 namespace ProjectExplorer {
 namespace Internal {
@@ -72,7 +69,7 @@ DependenciesModel::DependenciesModel(SessionManager *session,
             this, SLOT(resetModel()));
     connect(session, SIGNAL(projectAdded(ProjectExplorer::Project*)),
             this, SLOT(resetModel()));
-    connect(session, SIGNAL(sessionLoaded()),
+    connect(session, SIGNAL(sessionLoaded(QString)),
             this, SLOT(resetModel()));
 //    qDebug()<<"Dependencies Model"<<this<<"for project"<<project<<"("<<project->file()->fileName()<<")";
 }
@@ -114,7 +111,7 @@ QVariant DependenciesModel::data(const QModelIndex &index, int role) const
     case Qt::CheckStateRole:
         return m_session->hasDependency(m_project, p) ? Qt::Checked : Qt::Unchecked;
     case Qt::DecorationRole:
-        return Core::FileIconProvider::instance()->icon(QFileInfo(p->file()->fileName()));
+        return Core::FileIconProvider::instance()->icon(QFileInfo(p->document()->fileName()));
     default:
         return QVariant();
     }
@@ -275,6 +272,11 @@ QString DependenciesPanelFactory::displayName() const
     return QCoreApplication::translate("DependenciesPanelFactory", "Dependencies");
 }
 
+int DependenciesPanelFactory::priority() const
+{
+    return 50;
+}
+
 bool DependenciesPanelFactory::supports(Project *project)
 {
     Q_UNUSED(project);
@@ -285,7 +287,7 @@ PropertiesPanel *DependenciesPanelFactory::createPanel(Project *project)
 {
     PropertiesPanel *panel = new PropertiesPanel;
     panel->setWidget(new DependenciesWidget(m_session, project));
-    panel->setIcon(QIcon(":/projectexplorer/images/ProjectDependencies.png"));
+    panel->setIcon(QIcon(QLatin1String(":/projectexplorer/images/ProjectDependencies.png")));
     panel->setDisplayName(QCoreApplication::translate("DependenciesPanel", "Dependencies"));
     return panel;
 }
