@@ -1,70 +1,57 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (info@qt.nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef PROJECTNODES_H
 #define PROJECTNODES_H
 
-#include <QtCore/QObject>
-#include <QtCore/QStringList>
-#include <QtGui/QIcon>
-
-#include "runconfiguration.h"
 #include "projectexplorer_export.h"
 
+#include <QIcon>
+
+#include <QObject>
+#include <QStringList>
 
 QT_BEGIN_NAMESPACE
 class QFileInfo;
 QT_END_NAMESPACE
 
-
 namespace Core {
     class MimeDatabase;
 }
 
 namespace ProjectExplorer {
-
-//
-// = Node hierarchy =
-//
-//  The nodes are arranged in a tree where leaves are FileNodes and non-leaves are FolderNodes
-//  A Project is a special Folder that manages the files and normal folders underneath it.
-//
-//  The Watcher emits signals for structural changes in the hierarchy.
-//  A Visitor can be used to traverse all Projects and other Folders.
-//
+class RunConfiguration;
 
 enum NodeType {
     FileNodeType = 1,
     FolderNodeType,
+    VirtualFolderNodeType,
     ProjectNodeType,
     SessionNodeType
 };
@@ -88,7 +75,9 @@ class FolderNode;
 class ProjectNode;
 class NodesWatcher;
 class NodesVisitor;
+class SessionManager;
 
+// Documentation inside.
 class PROJECTEXPLORER_EXPORT Node : public QObject {
     Q_OBJECT
 public:
@@ -96,6 +85,8 @@ public:
     ProjectNode *projectNode() const;     // managing project
     FolderNode *parentFolderNode() const; // parent folder or project
     QString path() const;                 // file system path
+    virtual QString displayName() const;
+    virtual QString tooltip() const;
 
 protected:
     Node(NodeType nodeType, const QString &path);
@@ -103,7 +94,6 @@ protected:
     void setNodeType(NodeType type);
     void setProjectNode(ProjectNode *project);
     void setParentFolderNode(FolderNode *parentFolder);
-    void setPath(const QString &path);
 
 private:
     NodeType m_nodeType;
@@ -128,10 +118,11 @@ private:
     bool m_generated;
 };
 
+// Documentation inside.
 class PROJECTEXPLORER_EXPORT FolderNode : public Node {
     Q_OBJECT
 public:
-    explicit FolderNode(const QString &folderPath);
+    explicit FolderNode(const QString &folderPath, NodeType nodeType = FolderNodeType);
     virtual ~FolderNode();
 
     QString displayName() const;
@@ -156,6 +147,19 @@ private:
     mutable QIcon m_icon;
 };
 
+class PROJECTEXPLORER_EXPORT VirtualFolderNode : public FolderNode
+{
+    Q_OBJECT
+public:
+    explicit VirtualFolderNode(const QString &folderPath, int priority);
+    virtual ~VirtualFolderNode();
+
+    int priority() const;
+private:
+    int m_priority;
+};
+
+// Documentation inside.
 class PROJECTEXPLORER_EXPORT ProjectNode : public FolderNode
 {
     Q_OBJECT
@@ -221,8 +225,6 @@ public:
 
     void accept(NodesVisitor *visitor);
 
-    static bool sortNodesByPath(Node *n1, Node *n2);
-
 protected:
     // this is just the in-memory representation, a subclass
     // will add the persistent stuff
@@ -250,10 +252,12 @@ private:
     friend class SessionNode;
 };
 
+// Documentation inside.
 class PROJECTEXPLORER_EXPORT SessionNode : public FolderNode {
     Q_OBJECT
+    friend class SessionManager;
 public:
-    SessionNode(const QString &sessionFilePath, QObject *parentObject);
+    SessionNode(QObject *parentObject);
 
     QList<ProjectNode*> projectNodes() const;
 
@@ -275,6 +279,7 @@ private:
     QList<NodesWatcher*> m_watchers;
 };
 
+// Documentation inside.
 class PROJECTEXPLORER_EXPORT NodesWatcher : public QObject {
     Q_OBJECT
 public:
