@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "session.h"
 
@@ -61,7 +58,6 @@
 #include <QTimer>
 
 #include <QApplication>
-#include <QMainWindow>
 #include <QMessageBox>
 #include <QPushButton>
 #include <QTextCodec>
@@ -94,7 +90,8 @@ SessionManager::SessionManager(QObject *parent)
     m_sessionName(QLatin1String("default")),
     m_virginSession(true),
     m_loadingSession(false),
-    m_startupProject(0)
+    m_startupProject(0),
+    m_writer(0)
 {
     connect(ModeManager::instance(), SIGNAL(currentModeChanged(Core::IMode*)),
             this, SLOT(saveActiveMode(Core::IMode*)));
@@ -114,6 +111,7 @@ SessionManager::SessionManager(QObject *parent)
 SessionManager::~SessionManager()
 {
     emit aboutToUnloadSession(m_sessionName);
+    delete m_writer;
 }
 
 
@@ -131,7 +129,7 @@ bool SessionManager::isDefaultSession(const QString &session) const
 
 void SessionManager::saveActiveMode(Core::IMode *mode)
 {
-    setValue(QLatin1String("ActiveMode"), mode->id());
+    setValue(QLatin1String("ActiveMode"), mode->id().toString());
 }
 
 void SessionManager::clearProjectFileCache()
@@ -159,7 +157,7 @@ bool SessionManager::recursiveDependencyCheck(const QString &newDep, const QStri
 }
 
 /*
- * TODO: The dependency management exposes an interface based on projects, but
+ * The dependency management exposes an interface based on projects, but
  * is internally purely string based. This is suboptimal. Probably it would be
  * nicer to map the filenames to projects on load and only map it back to
  * filenames when saving.
@@ -269,6 +267,9 @@ void SessionManager::addProjects(const QList<Project*> &projects)
             connect(pro, SIGNAL(fileListChanged()),
                     this, SLOT(clearProjectFileCache()));
 
+            connect(pro, SIGNAL(displayNameChanged()),
+                    this, SLOT(projectDisplayNameChanged()));
+
             if (debug)
                 qDebug() << "SessionManager - adding project " << pro->displayName();
         }
@@ -304,21 +305,28 @@ bool SessionManager::save()
 
     emit aboutToSaveSession();
 
-    PersistentSettingsWriter writer;
-
-    // save the startup project
-    if (m_startupProject) {
-        writer.saveValue(QLatin1String("StartupProject"), m_startupProject->document()->fileName());
+    if (!m_writer || m_writer->fileName() != sessionNameToFileName(m_sessionName)) {
+        delete m_writer;
+        m_writer = new Utils::PersistentSettingsWriter(sessionNameToFileName(m_sessionName),
+                                                       QLatin1String("QtCreatorSession"));
     }
 
+    QVariantMap data;
+    // save the startup project
+    if (m_startupProject)
+        data.insert(QLatin1String("StartupProject"), m_startupProject->document()->fileName());
+
     QStringList projectFiles;
     foreach (Project *pro, m_projects)
         projectFiles << pro->document()->fileName();
 
     // Restore infromation on projects that failed to load:
-    projectFiles.append(m_failedProjects);
+    // don't readd projects to the list, which the user loaded
+    foreach (const QString &failed, m_failedProjects)
+        if (!projectFiles.contains(failed))
+            projectFiles << failed;
 
-    writer.saveValue(QLatin1String("ProjectList"), projectFiles);
+    data.insert(QLatin1String("ProjectList"), projectFiles);
 
     QMap<QString, QVariant> depMap;
     QMap<QString, QStringList>::const_iterator i = m_depMap.constBegin();
@@ -331,7 +339,7 @@ bool SessionManager::save()
         depMap.insert(key, values);
         ++i;
     }
-    writer.saveValue(QLatin1String("ProjectDependencies"), QVariant(depMap));
+    data.insert(QLatin1String("ProjectDependencies"), QVariant(depMap));
 
     int editorCount = 0;
     QList<Core::IEditor *> editors = ICore::editorManager()->openedEditors();
@@ -340,25 +348,23 @@ bool SessionManager::save()
         if (!editor->isTemporary())
             ++editorCount;
     }
-    writer.saveValue(QLatin1String("OpenEditors"), editorCount);
-    writer.saveValue(QLatin1String("EditorSettings"),
-                     ICore::editorManager()->saveState().toBase64());
+    data.insert(QLatin1String("OpenEditors"), editorCount);
+    data.insert(QLatin1String("EditorSettings"), ICore::editorManager()->saveState().toBase64());
 
     QMap<QString, QVariant>::const_iterator it, end;
     end = m_values.constEnd();
     QStringList keys;
     for (it = m_values.constBegin(); it != end; ++it) {
-        writer.saveValue(QLatin1String("value-") + it.key(), it.value());
+        data.insert(QLatin1String("value-") + it.key(), it.value());
         keys << it.key();
     }
 
-    writer.saveValue(QLatin1String("valueKeys"), keys);
+    data.insert(QLatin1String("valueKeys"), keys);
 
-    QString fileName = sessionNameToFileName(m_sessionName);
-    bool result = writer.save(fileName, QLatin1String("QtCreatorSession"), Core::ICore::mainWindow());
+    bool result = m_writer->save(data, Core::ICore::mainWindow());
     if (!result) {
         QMessageBox::warning(0, tr("Error while saving session"),
-                                tr("Could not save session to file %1").arg(fileName));
+                                tr("Could not save session to file %1").arg(m_writer->fileName().toUserOutput()));
     }
 
     if (debug)
@@ -642,9 +648,9 @@ QStringList SessionManager::sessions() const
     return m_sessions;
 }
 
-QString SessionManager::sessionNameToFileName(const QString &session) const
+Utils::FileName SessionManager::sessionNameToFileName(const QString &session) const
 {
-    return ICore::userResourcePath() + QLatin1Char('/') + session + QLatin1String(".qws");
+    return Utils::FileName::fromString(ICore::userResourcePath() + QLatin1Char('/') + session + QLatin1String(".qws"));
 }
 
 /*!
@@ -677,7 +683,7 @@ bool SessionManager::deleteSession(const QString &session)
     if (!m_sessions.contains(session))
         return false;
     m_sessions.removeOne(session);
-    QFile fi(sessionNameToFileName(session));
+    QFile fi(sessionNameToFileName(session).toString());
     if (fi.exists())
         return fi.remove();
     return false;
@@ -688,9 +694,9 @@ bool SessionManager::cloneSession(const QString &original, const QString &clone)
     if (!m_sessions.contains(original))
         return false;
 
-    QFile fi(sessionNameToFileName(original));
+    QFile fi(sessionNameToFileName(original).toString());
     // If the file does not exist, we can still clone
-    if (!fi.exists() || fi.copy(sessionNameToFileName(clone))) {
+    if (!fi.exists() || fi.copy(sessionNameToFileName(clone).toString())) {
         Q_ASSERT(m_sessions.size() > 0);
         m_sessions.insert(1, clone);
         return true;
@@ -713,14 +719,14 @@ void SessionManager::restoreDependencies(const Utils::PersistentSettingsReader &
     QMap<QString, QVariant>::const_iterator i = depMap.constBegin();
     while (i != depMap.constEnd()) {
         const QString &key = i.key();
-        if (m_failedProjects.contains(key))
-            continue;
-        QStringList values;
-        foreach (const QString &value, i.value().toStringList()) {
-            if (!m_failedProjects.contains(value))
-                values << value;
+        if (!m_failedProjects.contains(key)) {
+            QStringList values;
+            foreach (const QString &value, i.value().toStringList()) {
+                if (!m_failedProjects.contains(value))
+                    values << value;
+            }
+            m_depMap.insert(key, values);
         }
-        m_depMap.insert(key, values);
         ++i;
     }
 }
@@ -751,15 +757,17 @@ void SessionManager::restoreStartupProject(const Utils::PersistentSettingsReader
 {
     const QString startupProject = reader.restoreValue(QLatin1String("StartupProject")).toString();
     if (!startupProject.isEmpty()) {
-        const QString startupProjectPath = startupProject;
         foreach (Project *pro, m_projects) {
-            if (QDir::cleanPath(pro->document()->fileName()) == startupProjectPath) {
+            if (QDir::cleanPath(pro->document()->fileName()) == startupProject) {
                 setStartupProject(pro);
                 break;
             }
         }
-        if (!m_startupProject)
-            qWarning() << "Could not find startup project" << startupProjectPath;
+    }
+    if (!m_startupProject) {
+        qWarning() << "Could not find startup project" << startupProject;
+        if (!projects().isEmpty())
+            setStartupProject(projects().first());
     }
 }
 
@@ -806,12 +814,12 @@ bool SessionManager::loadSession(const QString &session)
         return false;
 
     // Try loading the file
-    QString fileName = sessionNameToFileName(session);
+    Utils::FileName fileName = sessionNameToFileName(session);
     PersistentSettingsReader reader;
-    if (QFileInfo(fileName).exists()) {
+    if (fileName.toFileInfo().exists()) {
         if (!reader.load(fileName)) {
             QMessageBox::warning(0, tr("Error while restoring session"),
-                                 tr("Could not restore session %1").arg(fileName));
+                                 tr("Could not restore session %1").arg(fileName.toUserOutput()));
             return false;
         }
     }
@@ -844,7 +852,7 @@ bool SessionManager::loadSession(const QString &session)
     m_sessionName = session;
     updateWindowTitle();
 
-    if (QFileInfo(fileName).exists()) {
+    if (fileName.toFileInfo().exists()) {
         m_virginSession = false;
 
         ICore::progressManager()->addTask(m_future.future(), tr("Session"),
@@ -871,13 +879,16 @@ bool SessionManager::loadSession(const QString &session)
 
         // restore the active mode
         QString modeIdentifier = value(QLatin1String("ActiveMode")).toString();
+        Id modeId;
         if (modeIdentifier.isEmpty())
-            modeIdentifier = QLatin1String(Core::Constants::MODE_EDIT);
+            modeId = Id(Core::Constants::MODE_EDIT);
+        else
+            modeId = Id(modeIdentifier);
 
-        ModeManager::activateMode(modeIdentifier);
+        ModeManager::activateMode(modeId);
         ModeManager::setFocusToCurrentMode();
     } else {
-        ModeManager::activateMode(QLatin1String(Core::Constants::MODE_EDIT));
+        ModeManager::activateMode(Id(Core::Constants::MODE_EDIT));
         ModeManager::setFocusToCurrentMode();
     }
     emit sessionLoaded(session);
@@ -916,13 +927,34 @@ void SessionManager::sessionLoadingProgress()
     QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
 }
 
+void SessionManager::projectDisplayNameChanged()
+{
+    Project *pro = qobject_cast<Project*>(sender());
+    if (pro) {
+        Node *currentNode = 0;
+        if (ProjectExplorerPlugin::currentProject() == pro)
+            currentNode = ProjectExplorerPlugin::instance()->currentNode();
+
+        // Fix node sorting
+        QList<ProjectNode *> nodes;
+        nodes << pro->rootProjectNode();
+        m_sessionNode->removeProjectNodes(nodes);
+        m_sessionNode->addProjectNodes(nodes);
+
+        if (currentNode)
+            ProjectExplorerPlugin::instance()->setCurrentNode(currentNode);
+
+        emit projectDisplayNameChanged(pro);
+    }
+}
+
 QStringList ProjectExplorer::SessionManager::projectsForSessionName(const QString &session) const
 {
-    const QString fileName = sessionNameToFileName(session);
+    const Utils::FileName fileName = sessionNameToFileName(session);
     PersistentSettingsReader reader;
-    if (QFileInfo(fileName).exists()) {
+    if (fileName.toFileInfo().exists()) {
         if (!reader.load(fileName)) {
-            qWarning() << "Could not restore session" << fileName;
+            qWarning() << "Could not restore session" << fileName.toUserOutput();
             return QStringList();
         }
     }
