@@ -1,39 +1,36 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "customdraganddrop.h"
 
-#include <QtCore/QMimeData>
-#include <QtCore/QPoint>
+#include <QMimeData>
+#include <QPoint>
 #include <QLabel>
 
 #include <QMouseEvent>
@@ -41,7 +38,7 @@
 #include <QDebug>
 #include <QPainter>
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) && QT_VERSION < 0x050000
 #include <private/qwidget_p.h>
 #endif
 
@@ -66,7 +63,7 @@ void CustomDragAndDropIcon::startDrag()
 
 void CustomDragAndDropIcon::grabMouseSafely()
 {
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) && QT_VERSION < 0x050000
     // grabMouse calls SetWindowsHookEx() - this function causes a system-wide
     // freeze if any other app on the system installs a hook and fails to
     // process events.
@@ -157,7 +154,7 @@ void CustomDragAndDropIcon::paintEvent(QPaintEvent *event)
 
 void CustomDragAndDropIcon::enter()
 {
-    connect(&m_timeLine, SIGNAL( frameChanged (int)), this, SLOT(animateDrag(int)));
+    connect(&m_timeLine, SIGNAL(frameChanged(int)), this, SLOT(animateDrag(int)));
     m_timeLine.setFrameRange(0, 10);
     m_timeLine.setDuration(10);
     m_timeLine.setLoopCount(1);
@@ -170,7 +167,7 @@ void CustomDragAndDropIcon::enter()
 
 void CustomDragAndDropIcon::leave()
 {
-    connect(&m_timeLine, SIGNAL( frameChanged (int)), this, SLOT(animateDrag(int)));
+    connect(&m_timeLine, SIGNAL(frameChanged(int)), this, SLOT(animateDrag(int)));
     m_timeLine.setFrameRange(0, 10);
     m_timeLine.setDuration(250);
     m_timeLine.setLoopCount(1);
