@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "qmljsfindreferences.h"
 
@@ -55,14 +52,14 @@
 
 #include "qmljseditorconstants.h"
 
-#include <QtCore/QTime>
-#include <QtCore/QTimer>
-#include <QtCore/QtConcurrentRun>
-#include <QtCore/QtConcurrentMap>
-#include <QtCore/QDir>
-#include <QtGui/QApplication>
-#include <QtGui/QLabel>
-#include <qtconcurrent/runextensions.h>
+#include <QTime>
+#include <QTimer>
+#include <QtConcurrentRun>
+#include <QtConcurrentMap>
+#include <QDir>
+#include <QApplication>
+#include <QLabel>
+#include <utils/runextensions.h>
 
 #include <functional>
 
@@ -246,13 +243,14 @@ protected:
 private:
     bool contains(const QmlComponentChain *chain)
     {
-        if (!chain || !chain->document())
+        if (!chain || !chain->document() || !chain->document()->bind())
             return false;
 
-        if (chain->document()->bind()->idEnvironment()->lookupMember(_name, _scopeChain.context()))
-            return chain->document()->bind()->idEnvironment() == _scope;
+        const ObjectValue *idEnv = chain->document()->bind()->idEnvironment();
+        if (idEnv && idEnv->lookupMember(_name, _scopeChain.context()))
+            return idEnv == _scope;
         const ObjectValue *root = chain->document()->bind()->rootObjectValue();
-        if (root->lookupMember(_name, _scopeChain.context())) {
+        if (root && root->lookupMember(_name, _scopeChain.context())) {
             return check(root);
         }
 
@@ -525,7 +523,7 @@ protected:
             if ((!_name.isEmpty()) && _name.at(0).isUpper()) {
                 // a possible type
                 _targetValue = _scopeChain->lookup(_name, &_scope);
-                if (value_cast<const ObjectValue*>(_targetValue))
+                if (value_cast<ObjectValue>(_targetValue))
                     _typeKind = TypeKind;
             }
         }
@@ -697,18 +695,23 @@ class ProcessFile: public std::unary_function<QString, QList<FindReferences::Usa
     typedef FindReferences::Usage Usage;
     QString name;
     const ObjectValue *scope;
+    QFutureInterface<Usage> *future;
 
 public:
     ProcessFile(const ContextPtr &context,
                 QString name,
-                const ObjectValue *scope)
-        : context(context), name(name), scope(scope)
+                const ObjectValue *scope,
+                QFutureInterface<Usage> *future)
+        : context(context), name(name), scope(scope), future(future)
     { }
 
     QList<Usage> operator()(const QString &fileName)
     {
         QList<Usage> usages;
-
+        if (future->isPaused())
+            future->waitForResume();
+        if (future->isCanceled())
+            return usages;
         Document::Ptr doc = context->snapshot().document(fileName);
         if (!doc)
             return usages;
@@ -718,7 +721,8 @@ public:
         FindUsages::Result results = findUsages(name, scope);
         foreach (const AST::SourceLocation &loc, results)
             usages.append(Usage(fileName, matchingLine(loc.offset, doc->source()), loc.startLine, loc.startColumn - 1, loc.length));
-
+        if (future->isPaused())
+            future->waitForResume();
         return usages;
     }
 };
@@ -729,18 +733,23 @@ class SearchFileForType: public std::unary_function<QString, QList<FindReference
     typedef FindReferences::Usage Usage;
     QString name;
     const ObjectValue *scope;
+    QFutureInterface<Usage> *future;
 
 public:
     SearchFileForType(const ContextPtr &context,
-                QString name,
-                const ObjectValue *scope)
-        : context(context), name(name), scope(scope)
+                      QString name,
+                      const ObjectValue *scope,
+                      QFutureInterface<Usage> *future)
+        : context(context), name(name), scope(scope), future(future)
     { }
 
     QList<Usage> operator()(const QString &fileName)
     {
         QList<Usage> usages;
-
+        if (future->isPaused())
+            future->waitForResume();
+        if (future->isCanceled())
+            return usages;
         Document::Ptr doc = context->snapshot().document(fileName);
         if (!doc)
             return usages;
@@ -750,7 +759,8 @@ public:
         FindTypeUsages::Result results = findUsages(name, scope);
         foreach (const AST::SourceLocation &loc, results)
             usages.append(Usage(fileName, matchingLine(loc.offset, doc->source()), loc.startLine, loc.startColumn - 1, loc.length));
-
+        if (future->isPaused())
+            future->waitForResume();
         return usages;
     }
 };
@@ -810,8 +820,8 @@ static void find_helper(QFutureInterface<FindReferences::Usage> &future,
         else
             language = QmlJSTools::languageOfFile(fileName);
 
-        Document::Ptr newDoc = snapshot.documentFromSource(it.value().first, fileName,
-                                                           language);
+        Document::MutablePtr newDoc = snapshot.documentFromSource(
+                    it.value().first, fileName, language);
         newDoc->parse();
         snapshot.insert(newDoc);
     }
@@ -851,12 +861,12 @@ static void find_helper(QFutureInterface<FindReferences::Usage> &future,
     FindReferences::Usage searchStarting(replacement, name, 0, 0, 0);
 
     if (findTarget.typeKind() == findTarget.TypeKind){
-        const ObjectValue *typeValue = value_cast<const ObjectValue*>(findTarget.targetValue());
+        const ObjectValue *typeValue = value_cast<ObjectValue>(findTarget.targetValue());
         if (!typeValue)
             return;
         future.reportResult(searchStarting);
 
-        SearchFileForType process(context, name, typeValue);
+        SearchFileForType process(context, name, typeValue, &future);
         UpdateUI reduce(&future);
 
         QtConcurrent::blockingMappedReduced<QList<FindReferences::Usage> > (files, process, reduce);
@@ -871,7 +881,7 @@ static void find_helper(QFutureInterface<FindReferences::Usage> &future,
             searchStarting.lineText.prepend(scope->className() + QLatin1Char('.'));
         future.reportResult(searchStarting);
 
-        ProcessFile process(context, name, scope);
+        ProcessFile process(context, name, scope, &future);
         UpdateUI reduce(&future);
 
         QtConcurrent::blockingMappedReduced<QList<FindReferences::Usage> > (files, process, reduce);
@@ -929,13 +939,14 @@ void FindReferences::displayResults(int first, int last)
         connect(m_currentSearch, SIGNAL(activated(Find::SearchResultItem)),
                 this, SLOT(openEditor(Find::SearchResultItem)));
         connect(m_currentSearch, SIGNAL(cancelled()), this, SLOT(cancel()));
-        Find::SearchResultWindow::instance()->popup(true);
+        connect(m_currentSearch, SIGNAL(paused(bool)), this, SLOT(setPaused(bool)));
+        Find::SearchResultWindow::instance()->popup(Core::IOutputPane::Flags(Core::IOutputPane::ModeSwitch | Core::IOutputPane::WithFocus));
 
-        Core::ProgressManager *progressManager = Core::ICore::instance()->progressManager();
+        Core::ProgressManager *progressManager = Core::ICore::progressManager();
         Core::FutureProgress *progress = progressManager->addTask(
                     m_watcher.future(), tr("Searching"),
                     QmlJSEditor::Constants::TASK_SEARCH);
-        connect(progress, SIGNAL(clicked()), Find::SearchResultWindow::instance(), SLOT(popup()));
+        connect(progress, SIGNAL(clicked()), m_currentSearch, SLOT(popup()));
 
         ++first;
     }
@@ -957,7 +968,7 @@ void FindReferences::displayResults(int first, int last)
 void FindReferences::searchFinished()
 {
     if (m_currentSearch)
-        m_currentSearch->finishSearch();
+        m_currentSearch->finishSearch(m_watcher.isCanceled());
     m_currentSearch = 0;
     emit changed();
 }
@@ -967,14 +978,21 @@ void FindReferences::cancel()
     m_watcher.cancel();
 }
 
+void FindReferences::setPaused(bool paused)
+{
+    if (!paused || m_watcher.isRunning()) // guard against pausing when the search is finished
+        m_watcher.setPaused(paused);
+}
+
 void FindReferences::openEditor(const Find::SearchResultItem &item)
 {
     if (item.path.size() > 0) {
-        TextEditor::BaseTextEditorWidget::openEditorAt(item.path.first(), item.lineNumber, item.textMarkPos,
-                                                 QString(),
-                                                 Core::EditorManager::ModeSwitch);
+        TextEditor::BaseTextEditorWidget::openEditorAt(QDir::fromNativeSeparators(item.path.first()),
+                                                       item.lineNumber, item.textMarkPos, Core::Id(),
+                                                       Core::EditorManager::ModeSwitch);
     } else {
-        Core::EditorManager::instance()->openEditor(item.text, QString(), Core::EditorManager::ModeSwitch);
+        Core::EditorManager::openEditor(QDir::fromNativeSeparators(item.text),
+                                        Core::Id(), Core::EditorManager::ModeSwitch);
     }
 }
 
