@@ -1,53 +1,46 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (info@qt.nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "qmakeparser.h"
 #include "qt4projectmanagerconstants.h"
 
-#include <projectexplorer/taskwindow.h>
+#include <projectexplorer/task.h>
 #include <projectexplorer/projectexplorerconstants.h>
 #include <utils/qtcassert.h>
 
-#include <QtCore/QDir>
-
 using namespace Qt4ProjectManager;
 using namespace Qt4ProjectManager::Internal;
 using ProjectExplorer::Task;
 
-QMakeParser::QMakeParser()
+QMakeParser::QMakeParser() : m_error(QLatin1String("^(.+):(\\d+):\\s(.+)$"))
 {
     setObjectName(QLatin1String("QMakeParser"));
-
-    m_error.setPattern("^(.+):(\\d+):\\s(.+)$");
     m_error.setMinimal(true);
 }
 
@@ -58,34 +51,34 @@ void QMakeParser::stdError(const QString &line)
         const QString description = lne.mid(15);
         emit addTask(Task(Task::Error,
                           description,
-                          QString() /* filename */,
+                          Utils::FileName() /* filename */,
                           -1 /* linenumber */,
-                          ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM));
+                          Core::Id(ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM)));
         return;
     }
     if (lne.startsWith(QLatin1String("Project WARNING:"))) {
         const QString description = lne.mid(17);
         emit addTask(Task(Task::Warning,
                           description,
-                          QString() /* filename */,
+                          Utils::FileName() /* filename */,
                           -1 /* linenumber */,
-                          ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM));
+                          Core::Id(ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM)));
         return;
     }
     if (m_error.indexIn(lne) > -1) {
-        QString fileName = QDir::fromNativeSeparators(m_error.cap(1));
+        QString fileName = m_error.cap(1);
         Task::TaskType type = Task::Error;
-        if (fileName.startsWith("WARNING: ")) {
+        if (fileName.startsWith(QLatin1String("WARNING: "))) {
             type = Task::Warning;
             fileName = fileName.mid(9);
-        } else if (fileName.startsWith("ERROR: ")) {
+        } else if (fileName.startsWith(QLatin1String("ERROR: "))) {
             fileName = fileName.mid(7);
         }
         emit addTask(Task(type,
                           m_error.cap(3) /* description */,
-                          fileName,
+                          Utils::FileName::fromUserInput(fileName),
                           m_error.cap(2).toInt() /* line */,
-                          ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM));
+                          Core::Id(ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM)));
         return;
     }
     IOutputParser::stdError(line);
@@ -106,6 +99,7 @@ using namespace ProjectExplorer;
 
 void Qt4ProjectManagerPlugin::testQmakeOutputParsers_data()
 {
+    const Core::Id categoryBuildSystem = Core::Id(ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM);
     QTest::addColumn<QString>("input");
     QTest::addColumn<OutputParserTester::Channel>("inputChannel");
     QTest::addColumn<QString>("childStdOutLines");
@@ -116,12 +110,12 @@ void Qt4ProjectManagerPlugin::testQmakeOutputParsers_data()
 
     QTest::newRow("pass-through stdout")
             << QString::fromLatin1("Sometext") << OutputParserTester::STDOUT
-            << QString::fromLatin1("Sometext") << QString()
+            << QString::fromLatin1("Sometext\n") << QString()
             << QList<ProjectExplorer::Task>()
             << QString();
     QTest::newRow("pass-through stderr")
             << QString::fromLatin1("Sometext") << OutputParserTester::STDERR
-            << QString() << QString::fromLatin1("Sometext")
+            << QString() << QString::fromLatin1("Sometext\n")
             << QList<ProjectExplorer::Task>()
             << QString();
 
@@ -132,8 +126,8 @@ void Qt4ProjectManagerPlugin::testQmakeOutputParsers_data()
             << (QList<ProjectExplorer::Task>()
                 << Task(Task::Error,
                         QLatin1String("undefined file"),
-                        QString(), -1,
-                        ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM))
+                        Utils::FileName(), -1,
+                        categoryBuildSystem))
             << QString();
 
     QTest::newRow("qMake Parse Error")
@@ -143,9 +137,9 @@ void Qt4ProjectManagerPlugin::testQmakeOutputParsers_data()
             << (QList<ProjectExplorer::Task>()
                 << Task(Task::Error,
                         QLatin1String("Parse Error ('sth odd')"),
-                        QDir::fromNativeSeparators(QLatin1String("e:\\project.pro")),
+                        Utils::FileName::fromUserInput("e:\\project.pro"),
                         14,
-                        ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM))
+                        categoryBuildSystem))
             << QString();
 
     QTest::newRow("qMake warning")
@@ -155,8 +149,8 @@ void Qt4ProjectManagerPlugin::testQmakeOutputParsers_data()
             << (QList<ProjectExplorer::Task>()
                 << Task(Task::Warning,
                         QLatin1String("bearer module might require ReadUserData capability"),
-                        QString(), -1,
-                        ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM))
+                        Utils::FileName(), -1,
+                        categoryBuildSystem))
             << QString();
 
     QTest::newRow("qMake warning with location")
@@ -166,8 +160,8 @@ void Qt4ProjectManagerPlugin::testQmakeOutputParsers_data()
             << (QList<ProjectExplorer::Task>()
                 << Task(Task::Warning,
                         QLatin1String("Unescaped backslashes are deprecated."),
-                        QLatin1String("e:/NokiaQtSDK/Simulator/Qt/msvc2008/lib/qtmaind.prl"), 1,
-                        ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM))
+                        Utils::FileName::fromUserInput("e:\\NokiaQtSDK\\Simulator\\Qt\\msvc2008\\lib\\qtmaind.prl"), 1,
+                        categoryBuildSystem))
             << QString();
 }
 
